<?php

namespace B2buy\SupplierMaster\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\SupplierMaster\Http\Requests\PolicyRequest;
use B2buy\SupplierMaster\Models\Policy;

/**
 * Admin web controller class.
 */
class PolicyWorkflowController extends BaseController
{

    /**
     * Workflow controller function for policy.
     *
     * @param Model   $policy
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PolicyRequest $request, Policy $policy, $step)
    {

        try {

            $policy->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('supplier_master::policy.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/policy/policy/' . $policy->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/policy/policy/' . $policy->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for policy.
     *
     * @param Model   $policy
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Policy $policy, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $policy->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('supplier_master::policy.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('supplier_master::admin.policy.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('supplier_master::admin.policy.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('supplier_master::admin.policy.message', $data)->render();

        }

    }
}
