<?php

namespace B2buy\SupplierMaster\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\SupplierMaster\Models\SupplierMaster;

class SupplierMasterPolicy
{

    /**
     * Determine if the given user can view the supplier_master.
     *
     * @param UserPolicy $user
     * @param SupplierMaster $supplier_master
     *
     * @return bool
     */
    public function view(UserPolicy $user, SupplierMaster $supplier_master)
    {
        if ($user->canDo('supplier_master.supplier_master.view') && $user->isAdmin()) {
            return true;
        }

        return $supplier_master->user_id == user_id() && $supplier_master->user_type == user_type();
    }

    /**
     * Determine if the given user can create a supplier_master.
     *
     * @param UserPolicy $user
     * @param SupplierMaster $supplier_master
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('supplier_master.supplier_master.create');
    }

    /**
     * Determine if the given user can update the given supplier_master.
     *
     * @param UserPolicy $user
     * @param SupplierMaster $supplier_master
     *
     * @return bool
     */
    public function update(UserPolicy $user, SupplierMaster $supplier_master)
    {
        if ($user->canDo('supplier_master.supplier_master.edit') && $user->isAdmin()) {
            return true;
        }

        return $supplier_master->user_id == user_id() && $supplier_master->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given supplier_master.
     *
     * @param UserPolicy $user
     * @param SupplierMaster $supplier_master
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SupplierMaster $supplier_master)
    {
        return $supplier_master->user_id == user_id() && $supplier_master->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given supplier_master.
     *
     * @param UserPolicy $user
     * @param SupplierMaster $supplier_master
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SupplierMaster $supplier_master)
    {
        if ($user->canDo('supplier_master.supplier_master.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given supplier_master.
     *
     * @param UserPolicy $user
     * @param SupplierMaster $supplier_master
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SupplierMaster $supplier_master)
    {
        if ($user->canDo('supplier_master.supplier_master.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
