<?php

namespace B2buy\SupplierMaster\Providers;

use Illuminate\Support\ServiceProvider;

class SupplierMasterServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'supplier_master');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'supplier_master');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSupplierMaster();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSupplierMaster()
    {
        $this->app->bind('supplier_master', function($app) {
            return new SupplierMaster($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('SupplierMaster', 'Lavalite\SupplierMaster\Facades\SupplierMaster');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('b2buy.supplier_master', function ($app) {
            return $this->app->make('B2buy\SupplierMaster\SupplierMaster');
        });

        // Bind SupplierMaster to repository
        $this->app->bind(
            'B2buy\SupplierMaster\Interfaces\SupplierMasterRepositoryInterface',
            \B2buy\SupplierMaster\Repositories\Eloquent\SupplierMasterRepository::class
        );        // Bind Policy to repository
        $this->app->bind(
            'B2buy\SupplierMaster\Interfaces\PolicyRepositoryInterface',
            \B2buy\SupplierMaster\Repositories\Eloquent\PolicyRepository::class
        );

        $this->app->register(\B2buy\SupplierMaster\Providers\AuthServiceProvider::class);
                $this->app->register(\B2buy\SupplierMaster\Providers\EventServiceProvider::class);
        
        $this->app->register(\B2buy\SupplierMaster\Providers\RouteServiceProvider::class);
                // $this->app->register(\B2buy\SupplierMaster\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and supplier_master's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'b2buy.supplier_master'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSupplierMaster::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['b2buy.supplier_master'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('b2buy/supplier_master.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/supplier_master')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/supplier_master')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
